==> haskell-xdg-basedir-0.2.2-13-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-xdg-basedir.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 xdg-basedir
version:              0.2.2
visibility:           public
id:                   xdg-basedir-0.2.2-BAENMrhgj9o4xkjbLJyx83
key:                  xdg-basedir-0.2.2-BAENMrhgj9o4xkjbLJyx83
license:              BSD-3-Clause
copyright:            (c) 2011 Will Donnelly
maintainer:           Will Donnelly <will.donnelly@gmail.com>
author:               Will Donnelly
stability:            alpha
homepage:             http://github.com/willdonnelly/xdg-basedir
synopsis:
    A basic implementation of the XDG Base Directory specification.

description:
    On Unix platforms, this should be a very straightforward
    implementation of the XDG Base Directory spec. On Windows,
    it will attempt to do the right thing with regards to
    choosing appropriate directories.

category:             System
abi:                  fe80635836ea94e01125da7e29095761
exposed:              True
exposed-modules:      System.Environment.XDG.BaseDir
import-dirs:          /usr/lib/ghc-9.2.8/site-local/xdg-basedir-0.2.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/xdg-basedir-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xdg-basedir
hs-libraries:         HSxdg-basedir-0.2.2-BAENMrhgj9o4xkjbLJyx83
depends:              base-4.16.4.0 directory-1.3.6.2 filepath-1.4.2.2
haddock-interfaces:   /usr/share/doc/haskell-xdg-basedir/html/xdg-basedir.haddock
haddock-html:         /usr/share/doc/haskell-xdg-basedir/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xdg-basedir-0.2.2-14-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-xdg-basedir.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xdg-basedir
version:              0.2.2
visibility:           public
id:                   xdg-basedir-0.2.2-GUgbFy73ZJ02w1NqlBIm8a
key:                  xdg-basedir-0.2.2-GUgbFy73ZJ02w1NqlBIm8a
license:              BSD-3-Clause
copyright:            (c) 2011 Will Donnelly
maintainer:           Will Donnelly <will.donnelly@gmail.com>
author:               Will Donnelly
stability:            alpha
homepage:             http://github.com/willdonnelly/xdg-basedir
synopsis:
    A basic implementation of the XDG Base Directory specification.

description:
    On Unix platforms, this should be a very straightforward
    implementation of the XDG Base Directory spec. On Windows,
    it will attempt to do the right thing with regards to
    choosing appropriate directories.

category:             System
abi:                  0ffc29b615e69fb415f415504524b802
exposed:              True
exposed-modules:      System.Environment.XDG.BaseDir
import-dirs:          /usr/lib/ghc-9.4.8/site-local/xdg-basedir-0.2.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/xdg-basedir-0.2.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/xdg-basedir-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xdg-basedir
hs-libraries:         HSxdg-basedir-0.2.2-GUgbFy73ZJ02w1NqlBIm8a
depends:              base-4.17.2.1 directory-1.3.7.1 filepath-1.4.2.2
haddock-interfaces:   /usr/share/doc/haskell-xdg-basedir/html/xdg-basedir.haddock
haddock-html:         /usr/share/doc/haskell-xdg-basedir/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
